@@ -1,4 +1,4 @@
-subroutine swap(j,k1,k2,shdswp,nadj,madj,x,y,ntot,eps,nerror)
+subroutine swap(j,k1,k2,shdswp,nadj,madj,x,y,ntot,eps,incAdj)
 
 # The segment k1->k2 is a diagonal of a quadrilateral
 # with a vertex at j (the point being added to the
@@ -13,33 +13,25 @@ logical shdswp, anticl
 
 # If vertices k1 and k2 are not connected there is no diagonal to swap.
 # This could happen if vertices j, k1, and k2 were colinear, but shouldn't.
-call adjchk(k1,k2,shdswp,nadj,madj,ntot,nerror)
-if(nerror > 0) {
-    return
-}
+call adjchk(k1,k2,shdswp,nadj,madj,ntot)
 if(!shdswp) return
 
 # Get the other vertex of the quadrilateral.
-call pred(k,k1,k2,nadj,madj,ntot,nerror) # If these aren't the same, then
-if(nerror > 0) return
-call succ(kk,k2,k1,nadj,madj,ntot,nerror) # there is no other vertex.
-if(nerror > 0) return
+call pred(k,k1,k2,nadj,madj,ntot)  # If these aren't the same, then
+call succ(kk,k2,k1,nadj,madj,ntot) # there is no other vertex.
 if(kk!=k) {
-        shdswp = .false.
-        return
+    shdswp = .false.
+    return
 }
 
 # Check whether the LOP is satisified; i.e. whether
 # vertex k is outside the circumcircle of vertices j, k1, and k2
-call qtest(j,k1,k,k2,shdswp,x,y,ntot,eps,nerror)
-if(nerror > 0) return
+call qtest(j,k1,k,k2,shdswp,x,y,ntot,eps)
 
 # Do the actual swapping.
 if(shdswp) {
-        call delet(k1,k2,nadj,madj,ntot,nerror)
-	if(nerror > 0) return
-	call insrt(j,k,nadj,madj,x,y,ntot,nerror,eps)
-	if(nerror > 0) return
+    call delet(k1,k2,nadj,madj,ntot)
+    call insrt(j,k,nadj,madj,x,y,ntot,eps,incAdj)
 }
 return
 end
